@@ -2,7 +2,7 @@
 from __future__ import print_function
 from inspect import getattr_static
 from itertools import chain
-from functools import partial, wraps
+from functools import lru_cache, partial, wraps
 
 iterchain = chain.from_iterable
 
@@ -12,6 +12,8 @@ from clu.exporting import Exporter
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
+cache = lambda function: export(lru_cache(maxsize=128, typed=True)(function))
+
 # PREDICATE LOGIC: negate(function) will “negate” a boolean predicate function –
 
 assigned = pytuple('doc', 'annotations')
@@ -201,7 +203,42 @@ rmro        = reverse(mro)
 isancestor  = lambda cls, ancestor=object: isclasstype(cls) and (ancestor in mro(cls))
 isorigin    = lambda cls, original=object: isclasstype(cls) and isancestor(origin(cls), typeof(original))
 
-newtype     = lambda name, *bases, **attributes: type(name, tuple(bases) or (object,), dict(attributes))
+class ObjectType(object):
+    """ Base type for programmatically created new types """
+    pass
+
+@cache
+def newtype(name, *bases, metaclass=None, attributes=None, **keywords):
+    """ newtype(name, *bases, metaclass=None, attributes=None, **keywords)
+        → Shortcut for “type(name, tuple(bases) or (ObjectType,), dict(attributes))”
+        
+        q.v. https://docs.python.org/3/library/types.html#dynamic-type-creation supra.
+    """
+    from clu.dicts import asdict
+    from clu.typespace import types
+    
+    # Default arguments:
+    if not bases:
+        bases = (ObjectType,)
+    if attributes is None:
+        attributes = {}
+    if ismetaclass(metaclass):
+        keywords['metaclass'] = metaclass
+    
+    # Resolve bases, prepare class namespace:
+    ordered_bases = types.resolve_bases(bases)
+    metacls, namespace, kwds = types.prepare_class(name, bases=ordered_bases,
+                                                         kwds=keywords)
+    
+    # Update namespace and keywords:
+    namespace.update(asdict(attributes))
+    kwds.update(keywords)
+    kwds['metaclass'] = metacls
+    
+    # Create and return the new class:
+    return types.new_class(name, bases=ordered_bases,
+                                 kwds=kwds,
+                                 exec_body=lambda ns: ns.update(namespace))
 
 # ENUM PREDICATES: `isenum(…)` predicate; `enumchoices(…)` to return a tuple
 # of strings naming an enum’s choices (like duh)
@@ -252,9 +289,6 @@ iscontainer     = lambda thing: isiterable(thing) and \
                             not isnormative(thing) and \
                             not isclasstype(thing)
 
-# HACKITTY HACK HACK HAAAAAAAACK:
-isnamespace     = lambda thing: typeof(thing).__name__.endswith('Namespace')
-
 # This is the equivalent of a lambda types’ built-in __repr__ function:
 lambda_repr     = lambda instance, default=λ: "<function %s at 0x%0x>" % (pyname(instance) or default,
                                                                               id(instance))
@@ -379,14 +413,12 @@ def tuplize(*items):
 @export
 @itervariadic
 def uniquify(*items):
-    """ uniquify(*items) → Return a tuple with a unique set of all non-`None` arguments """
+    """ uniquify(*items) → Return a generator yielding a unique set of all non-`None` arguments """
     seen = set() # type: set
-    stuff = []
     for item in filter(isnotnone, items):
         if item not in seen:
             seen.add(item)
-            stuff.append(item)
-    return tuple(stuff)
+            yield item
 
 @export
 @itervariadic
@@ -403,8 +435,8 @@ def union(*items):
 # UTILITY ANCESTOR PREDICATES: search through attributes across the MRO of a given type –
 # q.v. “resolve” meta-predicate supra.:
 
-ancestral       = lambda atx, cls, default=tuple(): collator(resolve,            atx, *rmro(cls), default=default)
-ancestral_union = lambda atx, cls, default=tuple(): uniquify(iterchain(ancestral(atx,       cls,  default=default)))
+ancestral       = lambda atx, cls, default=tuple():       collator(resolve,            atx, *rmro(cls), default=default)
+ancestral_union = lambda atx, cls, default=tuple(): tuple(uniquify(iterchain(ancestral(atx,       cls,  default=default))))
 
 # UTILITY FUNCTIONS: helpers for builtin predicate functions over iterables:
 
@@ -515,7 +547,6 @@ export(unwrap,          name='unwrap',          doc="unwrap(thing) → Return ei
 export(origin,          name='origin',          doc="origin(thing) → Return either `typeof(thing).__origin__` or `typeof(thing)` for a given `thing`")
 export(isancestor,      name='isancestor',      doc="isancestor(thing, ancestor=object) → boolean predicate, True if `ancestor` is found in “mro(thing)”")
 export(isorigin,        name='isorigin',        doc="isorigin(thing, original=object) → boolean predicate, True if `original` is an ancestor of “origin(thing)”")
-export(newtype,         name='newtype',         doc="newtype(name, *bases, **attributes) → Shortcut for “type(name, tuple(bases) or (object,), dict(attributes))”")
 
 export(predicate_nop,   name='predicate_nop',   doc="predicate_nop(thing) → boolean predicate that always returns `None`")
 export(function_nop,    name='function_nop',    doc="function_nop(*args) → variadic function always returns `None`")
@@ -530,7 +561,6 @@ export(pymodule,        name='pymodule',        doc="pymodule(thing) → Return
 export(isexpandable,    name='isexpandable',    doc="isexpandable(thing) → boolean predicate, True if `thing` can be `*expanded`")
 export(isnormative,     name='isnormative',     doc="isnormative(thing) → boolean predicate, True if `thing` is a string-like or bytes-like iterable")
 export(iscontainer,     name='iscontainer',     doc="iscontainer(thing) → boolean predicate, True if `thing` is iterable and not “normative” (q.v. `isnormative(…)` supra.)")
-export(isnamespace,     name='isnamespace',     doc="isnamespace(thing) → boolean predicate, True if the name of the type of “thing” ends with the string “Namespace” (hacky, I know – but functional!)")
 
 export(lambda_repr,     name='lambda_repr',     doc="lambda_repr(instance) → Equivalent to the built-in `__repr__(…)` method of a lambda function")
 
