@@ -342,12 +342,12 @@ class TestFsFilesystem(object):
     @pytest.mark.TODO
     def test_which_and_back_tick(self):
         """ Test clu.fs.which(…) and clu.fs.back_tick(…) against one another """
-        # TODO: un-hardcode this binary list, somehow
+        # TODO: ensure that these binaries are plausibly portable
         from clu.fs.filesystem import which, back_tick
         
-        BINARIES = ('ls', 'clang', 'gawk',
-                    'bpython',
-                    'bumpversion')
+        BINARIES = ('ls', 'cat', 'df',
+                    'python',
+                    'python-config')
         
         for binary in BINARIES:
             assert which(binary) == back_tick(f"which {binary}")
